<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://spai.site/
 * @since      1.0.0
 *
 * @package    Spai
 * @subpackage Spai/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @property   my_plugin_options
 * @package    Spai
 * @subpackage Spai/admin
 * @author     Author <admin@spai.site>
 */
class Spai_Admin
{

    /**
     * Default display_type.
     *
     * @since    1.1.5
     */
    const DISPLAY_TYPE_DEFAULT = 3;

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $plugin_name The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $version The current version of this plugin.
     */
    private $version;

    public $api;

    /**
     * Initialize the class and set its properties.
     *
     * @param string $plugin_name The name of this plugin.
     * @param string $version The version of this plugin.
     * @since    1.0.0
     */
    public function __construct($plugin_name, $version)
    {
        $this->plugin_name = $plugin_name;
        $this->version = $version;
        $this->my_plugin_options = get_option($this->plugin_name);

        $this->load_dependencies();
    }

    /**
     * Register the stylesheets for the admin area.
     *
     * @since    1.0.0
     */
    public function spai_enqueue_styles()
    {
        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Spai_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Spai_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        wp_enqueue_style($this->plugin_name . '-short_codes',
            plugin_dir_url(__FILE__) . '../public/css/spai-short_codes.css', array(), $this->version, 'all');
        wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/spai-admin.css', array(), $this->version,
            'all');
    }

    /**
     * Register the JavaScript for the admin area.
     *
     * @since    1.0.0
     */
    public function spai_enqueue_scripts()
    {
        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Spai_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Spai_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/spai-admin.js', array('jquery'),
            $this->version, false);
    }

    /**
     * Register the administration menu for this plugin into the WordPress Dashboard menu.
     *
     * @since    1.0.0
     */

    public function add_plugin_admin_menu()
    {
        /*
         * Add a settings page for this plugin to the Settings menu.
         *
         */
        add_options_page('Settings', 'Similar Posts AI', 'manage_options', $this->plugin_name,
            array($this, 'display_plugin_admin_page')
        );
    }

    /**
     * Add settings action link to the plugins page.
     *
     * @since    1.0.0
     */

    public function spai_add_action_links($links)
    {
        $settings_link = array(
            '<a href="' . admin_url('options-general.php?page=' . $this->plugin_name) . '">' . __('Settings',
                $this->plugin_name) . '</a>',
        );
        return array_merge($settings_link, $links);
    }

    /**
     * Render the settings page for this plugin.
     *
     * @since    1.0.0
     */

    public function display_plugin_admin_page()
    {
        $api_key = !empty($this->my_plugin_options['api_key']) ? $this->my_plugin_options['api_key'] : null;
        $checkToken = $this->api->checkToken();
        if (is_wp_error($checkToken)) {
            $error = $checkToken;
            include_once('partials/spai-admin-display-error.php');
        }

        if (
            !empty($api_key)
            && isset($checkToken['response']['code']) && $checkToken['response']['code'] == 200
        ) {
            $response = json_decode(json_decode($checkToken['body'], true), true);
            $balance = $response['user']['balance'];
            $heading = !empty($this->my_plugin_options['heading']) ? $this->my_plugin_options['heading'] : null;
            $default_image = !empty($this->my_plugin_options['default_image']) ? $this->my_plugin_options['default_image'] : null;
            $display_type = !empty($this->my_plugin_options['display_type']) ? $this->my_plugin_options['display_type'] : null;
            $title_max = !empty($this->my_plugin_options['title_max']) ? $this->my_plugin_options['title_max'] : null;
            $effect_of_increasing_the_image_size = !empty($this->my_plugin_options['effect_of_increasing_the_image_size']) ? $this->my_plugin_options['effect_of_increasing_the_image_size'] : null;
            $show_category = !empty($this->my_plugin_options['show_category']) ? $this->my_plugin_options['show_category'] : null;

            //spai_posts_data_sync count synced
            global $wpdb;
            $table_name = $wpdb->prefix . "spai_posts_data_sync";
            $check_posts_sync = $wpdb->get_results("SELECT * FROM " . $table_name);

            $total_posts_in_spai_posts_data_sync = count($check_posts_sync);
            $synced = 0;

            if ($check_posts_sync) {
                foreach ($check_posts_sync as $check_post_sync) {
                    if ($check_post_sync->is_sync == true) {
                        $synced++;
                    }
                }
            }

            include_once('partials/spai-admin-display.php');
        } else {
            include_once('partials/spai-admin-setup.php');
        }
    }


    /**
     * Validate options
     * @noinspection SuspiciousBinaryOperationInspection
     */
    public function validate($input)
    {
        $valid = array();
        $valid['api_key'] = (isset($input['api_key']) && !empty($input['api_key'])) ? sanitize_text_field($input['api_key']) : '';
        $valid['heading'] = (isset($input['heading']) && !empty($input['heading'])) ? sanitize_text_field($input['heading']) : '';
        $valid['default_image'] = (isset($input['default_image']) && !empty($input['default_image'])) ? esc_url_raw($input['default_image']) : '';

        $valid['display_type'] = ( isset( $input['display_type'] ) && !empty( $input['display_type'] ) ) ? (int) $input['display_type'] : self::DISPLAY_TYPE_DEFAULT;
        if( $valid['display_type'] > 5 || $valid['display_type'] < 1 ) { $valid['display_type'] = self::DISPLAY_TYPE_DEFAULT; }

        $valid['title_max'] = ( isset( $input['title_max'] ) && !empty( $input['title_max'] ) ) ? (int)$input['title_max'] : 50;

        if(isset($input['effect_of_increasing_the_image_size']) && (bool)$input['effect_of_increasing_the_image_size'] === true) {
            $valid['effect_of_increasing_the_image_size'] = true;
        } else {
            $valid['effect_of_increasing_the_image_size'] = false;
        }

        if(isset($input['show_category']) && (bool)$input['show_category'] === true) {
            $valid['show_category'] = true;
        } else {
            $valid['show_category'] = false;
        }

        return $valid;
    }

    /**
     * Update all options
     *
     */
    public function options_update()
    {
        register_setting($this->plugin_name, $this->plugin_name, array($this, 'validate'));
    }

    private function load_dependencies()
    {
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-spai-api.php';

        $this->api = new Spai_Api($this->my_plugin_options['api_key']);
    }

    public function addPostToTableSpaiPostsDataSync($post_id, $post)
    {
        if (in_array($post->post_type, array('post')) && in_array($post->post_status, array('publish'))) {
            global $wpdb;
            $table_name = $wpdb->prefix . "spai_posts_data_sync";

            $check = $wpdb->get_results("SELECT * FROM " . $table_name . ' WHERE post_id = ' . $post_id);
            if ($check) {
                $wpdb->update($table_name, array('is_sync' => false), array('post_id' => $post_id));
            } else {
                $wpdb->insert($table_name, array('post_id' => $post_id));
            }
        }
    }

}
